@@ -26,7 +26,7 @@ class SpotifySearch:
         """
             Init provider
         """
-        if not hasattr(self, '_cancel'):
+        if not hasattr(self, "_cancel"):
             self._cancel = Gio.Cancellable.new()
 
     def tracks(self, name):
@@ -36,32 +36,32 @@ class SpotifySearch:
         """
         try:
             formated = GLib.uri_escape_string(name, None, True).replace(
-                                                                      ' ', '+')
+                                                                      " ", "+")
             s = Lio.File.new_for_uri("https://api.spotify.com/v1/search?q=%s"
                                      "&type=track" % formated)
             (status, data, tag) = s.load_contents(self._cancel)
             if status:
-                decode = json.loads(data.decode('utf-8'))
+                decode = json.loads(data.decode("utf-8"))
                 tracks = []
-                for item in decode['tracks']['items']:
-                    if item['name'].lower() in tracks:
+                for item in decode["tracks"]["items"]:
+                    if item["name"].lower() in tracks:
                         continue
                     album_item = SearchItem()
                     search_item = SearchItem()
                     search_item.is_track = True
-                    search_item.name = item['name']
-                    album_item.name = item['name']
+                    search_item.name = item["name"]
+                    album_item.name = item["name"]
                     search_item.album = album_item
                     tracks.append(search_item.name.lower())
-                    search_item.tracknumber = int(item['track_number'])
-                    search_item.discnumber = int(item['disc_number'])
-                    search_item.duration = int(item['duration_ms']) / 1000
-                    search_item.cover = item['album']['images'][0]['url']
-                    search_item.smallcover = item['album']['images'][2]['url']
-                    for artist in item['artists']:
-                        search_item.artists.append(artist['name'])
+                    search_item.tracknumber = int(item["track_number"])
+                    search_item.discnumber = int(item["disc_number"])
+                    search_item.duration = int(item["duration_ms"]) / 1000
+                    search_item.cover = item["album"]["images"][0]["url"]
+                    search_item.smallcover = item["album"]["images"][2]["url"]
+                    for artist in item["artists"]:
+                        search_item.artists.append(artist["name"])
                     self._items.append(search_item)
-                    GLib.idle_add(self.emit, 'item-found')
+                    GLib.idle_add(self.emit, "item-found")
         except Exception as e:
             print("SpotifySearch::tracks(): %s" % e)
 
@@ -85,8 +85,8 @@ class SpotifySearch:
                                      "tracks/%s" % track_id)
             (status, data, tag) = s.load_contents(self._cancel)
             if status:
-                decode = json.loads(data.decode('utf-8'))
-                return decode['album']['id']
+                decode = json.loads(data.decode("utf-8"))
+                return decode["album"]["id"]
         except Exception as e:
             print("SpotifySearch::get_album_id():", e, track_id)
 
@@ -101,30 +101,30 @@ class SpotifySearch:
                                      "albums/%s" % album_id)
             (status, data, tag) = s.load_contents(self._cancel)
             if status:
-                decode = json.loads(data.decode('utf-8'))
+                decode = json.loads(data.decode("utf-8"))
                 album_item = SearchItem()
-                album_item.name = decode['name']
-                album_item.cover = decode['images'][0]['url']
-                album_item.smallcover = decode['images'][2]['url']
+                album_item.name = decode["name"]
+                album_item.cover = decode["images"][0]["url"]
+                album_item.smallcover = decode["images"][2]["url"]
                 album_item.ex_id = album_id
-                for item in decode['tracks']['items']:
+                for item in decode["tracks"]["items"]:
                     track_item = SearchItem()
                     track_item.is_track = True
-                    track_item.name = item['name']
+                    track_item.name = item["name"]
                     track_item.album = album_item.name
                     try:
                         track_item.year = decode[
-                                                'release_date'][:4]
+                                                "release_date"][:4]
                     except:
                         pass  # May be missing
                     track_item.tracknumber = int(
-                                              item['track_number'])
+                                              item["track_number"])
                     track_item.discnumber = int(
-                                               item['disc_number'])
+                                               item["disc_number"])
                     track_item.duration = int(
-                                        item['duration_ms']) / 1000
-                    for artist in item['artists']:
-                        track_item.artists.append(artist['name'])
+                                        item["duration_ms"]) / 1000
+                    for artist in item["artists"]:
+                        track_item.artists.append(artist["name"])
                     if not album_item.artists:
                         album_item.artists = track_item.artists
                     album_item.subitems.append(track_item)
@@ -144,24 +144,24 @@ class SpotifySearch:
                                      "tracks/%s" % track_id)
             (status, data, tag) = s.load_contents(self._cancel)
             if status:
-                decode = json.loads(data.decode('utf-8'))
+                decode = json.loads(data.decode("utf-8"))
                 album_item = SearchItem()
-                album_item.name = decode['album']['name']
-                album_item.cover = decode['album']['images'][0]['url']
-                album_item.smallcover = decode['album']['images'][2]['url']
+                album_item.name = decode["album"]["name"]
+                album_item.cover = decode["album"]["images"][0]["url"]
+                album_item.smallcover = decode["album"]["images"][2]["url"]
 
                 track_item = SearchItem()
                 track_item.is_track = True
-                track_item.name = decode['name']
+                track_item.name = decode["name"]
                 track_item.album = album_item
                 track_item.tracknumber = int(
-                                          decode['track_number'])
+                                          decode["track_number"])
                 track_item.discnumber = int(
-                                           decode['disc_number'])
+                                           decode["disc_number"])
                 track_item.duration = int(
-                                    decode['duration_ms']) / 1000
-                for artist in decode['artists']:
-                    track_item.artists.append(artist['name'])
+                                    decode["duration_ms"]) / 1000
+                for artist in decode["artists"]:
+                    track_item.artists.append(artist["name"])
                 album_item.artists = track_item.artists
                 album_item.subitems.append(track_item)
                 return album_item
@@ -180,37 +180,37 @@ class SpotifySearch:
         try:
             # Read album list
             formated = GLib.uri_escape_string(name, None, True).replace(
-                                                                      ' ', '+')
+                                                                      " ", "+")
             s = Lio.File.new_for_uri("https://api.spotify.com/v1/search?q=%s"
                                      "&type=artist" % formated)
             (status, data, tag) = s.load_contents(self._cancel)
             if status:
-                decode = json.loads(data.decode('utf-8'))
+                decode = json.loads(data.decode("utf-8"))
                 # For each album, get cover and tracks
                 artists = []
-                for item in decode['artists']['items']:
+                for item in decode["artists"]["items"]:
                     album_items = []
-                    artist_id = item['id']
-                    if item['name'].lower() in artists:
+                    artist_id = item["id"]
+                    if item["name"].lower() in artists:
                         continue
-                    artists.append(item['name'].lower())
+                    artists.append(item["name"].lower())
                     s = Lio.File.new_for_uri("https://api.spotify.com/"
                                              "v1/artists/%s/albums" %
                                              artist_id)
                     (status, data, tag) = s.load_contents(self._cancel)
                     if status:
-                        decode = json.loads(data.decode('utf-8'))
+                        decode = json.loads(data.decode("utf-8"))
                         albums = []
-                        for item in decode['items']:
-                            if item['name'].lower() in albums:
+                        for item in decode["items"]:
+                            if item["name"].lower() in albums:
                                 continue
                             album_item = SearchItem()
-                            album_item.name = item['name']
+                            album_item.name = item["name"]
                             albums.append(album_item.name.lower())
-                            album_item.cover = item['images'][0]['url']
-                            album_item.smallcover = item['images'][2]['url']
+                            album_item.cover = item["images"][0]["url"]
+                            album_item.smallcover = item["images"][2]["url"]
                             album_items.append(album_item)
-                            album_item.ex_id = item['id']
+                            album_item.ex_id = item["id"]
 
                     for album_item in album_items:
                         s = Lio.File.new_for_uri("https://api.spotify.com/v1/"
@@ -218,30 +218,30 @@ class SpotifySearch:
                                                  album_item.ex_id)
                         (status, data, tag) = s.load_contents(self._cancel)
                         if status:
-                            decode = json.loads(data.decode('utf-8'))
-                            for item in decode['tracks']['items']:
+                            decode = json.loads(data.decode("utf-8"))
+                            for item in decode["tracks"]["items"]:
                                 track_item = SearchItem()
                                 track_item.is_track = True
-                                track_item.name = item['name']
+                                track_item.name = item["name"]
                                 track_item.album = album_item
                                 try:
                                     track_item.year = decode[
-                                                            'release_date'][:4]
+                                                            "release_date"][:4]
                                 except:
                                     pass  # May be missing
                                 track_item.tracknumber = int(
-                                                          item['track_number'])
+                                                          item["track_number"])
                                 track_item.discnumber = int(
-                                                           item['disc_number'])
+                                                           item["disc_number"])
                                 track_item.duration = int(
-                                                    item['duration_ms']) / 1000
-                                for artist in item['artists']:
-                                    track_item.artists.append(artist['name'])
+                                                    item["duration_ms"]) / 1000
+                                for artist in item["artists"]:
+                                    track_item.artists.append(artist["name"])
                                 if not album_item.artists:
                                     album_item.artists = track_item.artists
                                 album_item.subitems.append(track_item)
                         self._items.append(album_item)
-                        GLib.idle_add(self.emit, 'item-found')
+                        GLib.idle_add(self.emit, "item-found")
         except Exception as e:
             print("SpotifySearch::albums(): %s" % e)
 
@@ -253,44 +253,44 @@ class SpotifySearch:
         try:
             # Read album list
             formated = GLib.uri_escape_string(name, None, True).replace(
-                                                                      ' ', '+')
+                                                                      " ", "+")
             s = Lio.File.new_for_uri("https://api.spotify.com/v1/search?q=%s"
                                      "&type=album" % formated)
             (status, data, tag) = s.load_contents(self._cancel)
             if status:
-                decode = json.loads(data.decode('utf-8'))
+                decode = json.loads(data.decode("utf-8"))
                 # For each album, get cover and tracks
-                for item in decode['albums']['items']:
+                for item in decode["albums"]["items"]:
                     album_item = SearchItem()
-                    album_item.name = item['name']
+                    album_item.name = item["name"]
                     album_item.is_track = False
-                    album_item.cover = item['images'][0]['url']
-                    album_item.smallcover = item['images'][2]['url']
+                    album_item.cover = item["images"][0]["url"]
+                    album_item.smallcover = item["images"][2]["url"]
                     s = Lio.File.new_for_uri("https://api.spotify.com/v1/"
-                                             "albums/%s" % item['id'])
+                                             "albums/%s" % item["id"])
                     (status, data, tag) = s.load_contents(self._cancel)
                     if status:
-                        decode = json.loads(data.decode('utf-8'))
-                        for item in decode['tracks']['items']:
+                        decode = json.loads(data.decode("utf-8"))
+                        for item in decode["tracks"]["items"]:
                             track_item = SearchItem()
                             track_item.is_track = True
                             try:
                                 track_item.year = decode[
-                                                        'release_date'][:4]
+                                                        "release_date"][:4]
                             except:
                                 pass  # May be missing
-                            track_item.name = item['name']
+                            track_item.name = item["name"]
                             track_item.album = album_item
-                            track_item.tracknumber = int(item['track_number'])
-                            track_item.discnumber = int(item['disc_number'])
-                            track_item.duration = int(item['duration_ms'])\
+                            track_item.tracknumber = int(item["track_number"])
+                            track_item.discnumber = int(item["disc_number"])
+                            track_item.duration = int(item["duration_ms"])\
                                 / 1000
-                            for artist in item['artists']:
-                                track_item.artists.append(artist['name'])
+                            for artist in item["artists"]:
+                                track_item.artists.append(artist["name"])
                             if not album_item.artists:
                                 album_item.artists = track_item.artists
                             album_item.subitems.append(track_item)
                     self._items.append(album_item)
-                    GLib.idle_add(self.emit, 'item-found')
+                    GLib.idle_add(self.emit, "item-found")
         except Exception as e:
             print("SpotifySearch::albums(): %s" % e)
